function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import RabbitMQBusError from './rabbitmq-error';
import defaultOptions from './default-options';

const init = async (amqp, pool, onMessage) => {
  pool.config = _objectSpread({}, defaultOptions, pool.config);

  try {
    const {
      url,
      exchange,
      exchangeType,
      queueName,
      messageTtl,
      maxLength
    } = pool.config;
    const connection = await amqp.connect(url);
    const channel = await connection.createChannel();
    await channel.assertExchange(exchange, exchangeType, {
      durable: false
    });
    const queue = await channel.assertQueue(queueName, {
      arguments: {
        messageTtl: messageTtl,
        maxLength: maxLength
      }
    });
    await channel.bindQueue(queue.queue, exchange);
    await channel.consume(queueName, onMessage, {
      noAck: true
    });
    Object.assign(pool, {
      connection,
      channel,
      queue
    });
  } catch (error) {
    throw new RabbitMQBusError(error.message, error.stack, error.cause);
  }
};

export default init;
//# sourceMappingURL=init.js.map