"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _rabbitmqError = _interopRequireDefault(require("./rabbitmq-error"));

var _defaultOptions = _interopRequireDefault(require("./default-options"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const init = async (amqp, pool, onMessage) => {
  pool.config = _objectSpread({}, _defaultOptions.default, pool.config);

  try {
    const {
      url,
      exchange,
      exchangeType,
      queueName,
      messageTtl,
      maxLength
    } = pool.config;
    const connection = await amqp.connect(url);
    const channel = await connection.createChannel();
    await channel.assertExchange(exchange, exchangeType, {
      durable: false
    });
    const queue = await channel.assertQueue(queueName, {
      arguments: {
        messageTtl: messageTtl,
        maxLength: maxLength
      }
    });
    await channel.bindQueue(queue.queue, exchange);
    await channel.consume(queueName, onMessage, {
      noAck: true
    });
    Object.assign(pool, {
      connection,
      channel,
      queue
    });
  } catch (error) {
    throw new _rabbitmqError.default(error.message, error.stack, error.cause);
  }
};

var _default = init;
exports.default = _default;
//# sourceMappingURL=init.js.map